@@ -464,6 +464,9 @@ SERVICE_VERSIONS = {
     "ocr": [
         "2018-11-19"
     ],
+    "omics": [
+        "2022-11-28"
+    ],
     "organization": [
         "2021-03-31",
         "2018-12-25"
